@@ -17,40 +17,39 @@
 #' @importFrom httr GET
 #' @import dplyr
 #' @import tidyr
+#' @family CFBD Conference Functions
 #' @export
 #' @examples
 #' \donttest{
 #'   try(cfbd_conferences())
 #' }
 cfbd_conferences <- function() {
-  full_url <- "https://api.collegefootballdata.com/conferences"
 
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  # Validation ----
+  validate_api_key()
+
+  # Query API ----
+  full_url <- "https://api.collegefootballdata.com/conferences"
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
-        jsonlite::fromJSON()
+        jsonlite::fromJSON() %>%
+        janitor::clean_names()
 
       # Rename id as conference_id, short_name as long_name
       df <- df %>%
         dplyr::rename(
-          conference_id = .data$id,
-          long_name = .data$short_name
+          "conference_id" = "id",
+          "long_name" = "short_name"
         )
 
       df <- df %>%
