@@ -45,10 +45,10 @@ NULL
 #' @keywords NFL Teams
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
 #' @importFrom janitor clean_names
+#' @family CFBD Draft
 #' @export
 #' @examples
 #' \donttest{
@@ -57,26 +57,18 @@ NULL
 #'
 cfbd_draft_teams <- function() {
 
-  base_url <- "https://api.collegefootballdata.com/draft/teams"
-
-  # Create full url using base and input arguments
-  full_url <- base_url
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  # Validation ----
+  validate_api_key()
 
+  # Query API ----
+  full_url <- "https://api.collegefootballdata.com/draft/teams"
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
@@ -86,10 +78,10 @@ cfbd_draft_teams <- function() {
         janitor::clean_names() %>%
         as.data.frame() %>%
         dplyr::rename(
-          nfl_location = .data$location,
-          nfl_nickname = .data$nickname,
-          nfl_display_name = .data$display_name,
-          nfl_logo = .data$logo
+          "nfl_location" = "location",
+          "nfl_nickname" = "nickname",
+          "nfl_display_name" = "display_name",
+          "nfl_logo" = "logo"
         )
       df <- df %>%
         make_cfbfastR_data("NFL teams data from CollegeFootballData.com",Sys.time())
@@ -114,10 +106,10 @@ cfbd_draft_teams <- function() {
 #' @keywords NFL Positions
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
 #' @importFrom janitor clean_names
+#' @family CFBD Draft
 #' @export
 #' @examples
 #' \donttest{
@@ -126,25 +118,18 @@ cfbd_draft_teams <- function() {
 #'
 cfbd_draft_positions <- function() {
 
-  base_url <- "https://api.collegefootballdata.com/draft/positions"
+  # Validation ----
+  validate_api_key()
 
-  # Create full url using base and input arguments
-  full_url <- base_url
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  # Query API ----
+  full_url <- "https://api.collegefootballdata.com/draft/positions"
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
@@ -154,8 +139,8 @@ cfbd_draft_positions <- function() {
         janitor::clean_names() %>%
         as.data.frame() %>%
         dplyr::rename(
-          position_name = .data$name,
-          position_abbreviation = .data$abbreviation
+          "position_name" = "name",
+          "position_abbreviation" = "abbreviation"
         )
 
       df <- df %>%
@@ -186,6 +171,7 @@ cfbd_draft_positions <- function() {
 #'   \item{`college_id`: integer}{College team referencing id.}
 #'   \item{`college_team`: character}{College team name.}
 #'   \item{`college_conference`: character}{Conference of college team.}
+#'   \item{`nfl_team_id`: integer.}{NFL team ID.}
 #'   \item{`nfl_team`: character}{NFL team name of drafted player.}
 #'   \item{`year`: integer.}{NFL draft class year.}
 #'   \item{`overall`: integer.}{Overall draft pick number.}
@@ -208,10 +194,10 @@ cfbd_draft_positions <- function() {
 #' @keywords NFL Draft Picks
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
 #' @importFrom janitor clean_names
+#' @family CFBD Draft
 #' @export
 #' @examples
 #' \donttest{
@@ -225,55 +211,31 @@ cfbd_draft_picks <- function(year = NULL,
                              college = NULL,
                              conference = NULL,
                              position = NULL) {
-  if (!is.null(year) & !(is.numeric(year) & nchar(year) == 4)) {
-    # Check if year is numeric, if not NULL
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
-  if (!is.null(nfl_team)) {
-    # Encode team parameter for URL if not NULL
-    nfl_team <- utils::URLencode(nfl_team, reserved = TRUE)
-  }
-  if (!is.null(college)) {
-    if (college == "San Jose State") {
-      college <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      college <- utils::URLencode(college, reserved = TRUE)
-    }
-  }
-  if (!is.null(conference)) {
-    conference <- utils::URLencode(conference, reserved = TRUE)
-  }
-  if (!is.null(position)) {
-    position <- utils::URLencode(position, reserved = TRUE)
-  }
 
-  base_url <- "https://api.collegefootballdata.com/draft/picks?"
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
 
-  # Create full url using base and input arguments
-  full_url <- paste0(
-    base_url,
-    "year=", year,
-    "&nflTeam=", nfl_team,
-    "&college=", college,
-    "&conference=", conference,
-    "&position=", position
+  # Team Name Handling ----
+  college <- handle_accents(college)
+
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/draft/picks"
+  query_params <- list(
+    "year" = year,
+    "nflTeam" = nfl_team,
+    "college" = college,
+    "conference" = conference,
+    "position" = position
   )
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
-
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
