@@ -54,12 +54,12 @@ NULL
 #' @keywords Players
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET RETRY
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom janitor clean_names
 #' @importFrom glue glue
 #' @import dplyr
 #' @import tidyr
+#' @family CFBD Players
 #' @export
 #' @examples
 #' \donttest{
@@ -72,67 +72,47 @@ cfbd_player_info <- function(search_term,
                              team = NULL,
                              year = NULL) {
 
-  # Encode search_term parameter for URL
-  search_term <- utils::URLencode(search_term, reserved = TRUE)
-
-  # Position Group vector to check input arguments against
+  # Validation Lists ----
   pos_groups <- c(
     "QB", "RB", "FB", "TE", "WR", "OL", "OT", "G", "OC",
     "DB", "CB", "S", "LB", "DE", "NT", "DL", "DT",
     "K", "P", "PK", "LS"
   )
 
-  if (!is.null(position)&&!(position %in% pos_groups)) {
-    ## check if position in position group set
-    cli::cli_abort("Enter valid position group\nOffense: QB, RB, FB, TE, WR,  OL, G, OT, C\nDefense: DB, CB, S, LB, DL, DE, DT, NT\nSpecial Teams: K, P, LS, PK")
-  }
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
+  # Validation ----
+  validate_api_key()
+  validate_list(position, pos_groups)
+  validate_year(year)
 
-  # Check if year is numeric
-  if(!is.null(year) && !is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
-  base_url <- "https://api.collegefootballdata.com/player/search?"
+  # Team Name Handling ----
+  team <- handle_accents(team)
 
-  # Create full url using base and input arguments
-  full_url <- paste0(
-    base_url,
-    "searchTerm=", search_term,
-    "&position=", position,
-    "&team=", team,
-    "&year=", year
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/player/search"
+  query_params <- list(
+    "searchTerm" = search_term,
+    "position" = position,
+    "team" = team,
+    "year" = year
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
-
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- get_req(full_url)
+      check_status(res)
       # Get the content and return it as data.frame
+
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON(flatten = TRUE) %>%
         janitor::clean_names() %>%
         dplyr::rename(
-          athlete_id = .data$id,
-          home_town = .data$hometown
+          "athlete_id" = "id",
+          "home_town" = "hometown"
         )
 
 
@@ -142,8 +122,6 @@ cfbd_player_info <- function(search_term,
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments or no player info data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -154,7 +132,7 @@ cfbd_player_info <- function(search_term,
 
 #' @title
 #' **Get player returning production**
-#' @param year (*Integer* required, default 2019): Year, 4 digit format (*YYYY*).
+#' @param year (*Integer* required, default most recent season): Year, 4 digit format (*YYYY*).
 #' @param team (*String* optional): Team - Select a valid team, D1 football
 #' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
 #' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
@@ -180,79 +158,59 @@ cfbd_player_info <- function(search_term,
 #' @keywords Returning Production
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET RETRY
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
 #' @importFrom dplyr rename
+#' @family CFBD Players
 #' @export
 #' @examples
 #' \donttest{
 #'    try(cfbd_player_returning(year = 2019, team = "Florida State"))
 #' }
 #'
-cfbd_player_returning <- function(year = 2019,
+cfbd_player_returning <- function(year = most_recent_cfb_season(),
                                   team = NULL,
                                   conference = NULL) {
 
-  # Check if year is numeric
-  if(!is.null(year) && !is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
-  if (!is.null(conference)) {
-    # # Check conference parameter in conference abbreviations, if not NULL
-    # Encode conference parameter for URL, if not NULL
-    conference <- utils::URLencode(conference, reserved = TRUE)
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
 
-  base_url <- "https://api.collegefootballdata.com/player/returning?"
+  # Team Name Handling ----
+  team <- handle_accents(team)
 
-  # Create full url using base and input arguments
-  full_url <- paste0(
-    base_url,
-    "year=", year,
-    "&team=", team,
-    "&conference=", conference
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/player/returning"
+  query_params <- list(
+    "year" = year,
+    "team" = team,
+    "conference" = conference
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
-
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
+      # Create the GET request and set response as res
+      res <- get_req(full_url)
+      check_status(res)
+
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON() %>%
         dplyr::rename(
-          total_ppa = .data$totalPPA,
-          total_passing_ppa = .data$totalPassingPPA,
-          total_receiving_ppa = .data$totalReceivingPPA,
-          total_rushing_ppa = .data$totalRushingPPA,
-          percent_ppa = .data$percentPPA,
-          percent_passing_ppa = .data$percentPassingPPA,
-          percent_receiving_ppa = .data$percentReceivingPPA,
-          percent_rushing_ppa = .data$percentRushingPPA,
-          passing_usage = .data$passingUsage,
-          receiving_usage = .data$receivingUsage,
-          rushing_usage = .data$rushingUsage
+          "total_ppa" = "totalPPA",
+          "total_passing_ppa" = "totalPassingPPA",
+          "total_receiving_ppa" = "totalReceivingPPA",
+          "total_rushing_ppa" = "totalRushingPPA",
+          "percent_ppa" = "percentPPA",
+          "percent_passing_ppa" = "percentPassingPPA",
+          "percent_receiving_ppa" = "percentReceivingPPA",
+          "percent_rushing_ppa" = "percentRushingPPA",
+          "passing_usage" = "passingUsage",
+          "receiving_usage" = "receivingUsage",
+          "rushing_usage" = "rushingUsage"
         )
 
 
@@ -262,8 +220,6 @@ cfbd_player_returning <- function(year = 2019,
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments or no returning player data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -272,7 +228,7 @@ cfbd_player_returning <- function(year = 2019,
 
 #' @title
 #' **Get player usage metrics**
-#' @param year (*Integer* required, default 2019): Year, 4 digit format (*YYYY*).
+#' @param year (*Integer* required, default most recent season): Year, 4 digit format (*YYYY*).
 #' @param team (*String* optional): Team - Select a valid team, D1 football
 #' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
 #' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
@@ -305,89 +261,61 @@ cfbd_player_returning <- function(year = 2019,
 #' @keywords Player Usage
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET RETRY
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
 #' @importFrom purrr map_if
 #' @importFrom dplyr as_tibble rename
+#' @family CFBD Players
 #' @export
 #' @examples
 #' \donttest{
 #'   try(cfbd_player_usage(year = 2019, position = "WR", team = "Florida State"))
 #' }
 #'
-cfbd_player_usage <- function(year = 2019,
+cfbd_player_usage <- function(year = most_recent_cfb_season(),
                               team = NULL,
                               conference = NULL,
                               position = NULL,
                               athlete_id = NULL,
                               excl_garbage_time = FALSE) {
 
-  # Position Group vector to check input arguments against
+  # Validation Lists ----
   pos_groups <- c(
     "QB", "RB", "FB", "TE", "WR", "OL", "OT", "G", "OC",
     "DB", "CB", "S", "LB", "DE", "NT", "DL", "DT",
     "K", "P", "PK", "LS"
   )
-  # Check if year is numeric
-  if(!is.null(year) && !is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
-  if (!is.null(conference)) {
-    # # Check conference parameter in conference abbreviations, if not NULL
-    # Encode conference parameter for URL, if not NULL
-    conference <- utils::URLencode(conference, reserved = TRUE)
-  }
-  if (!is.null(position)&&!(position %in% pos_groups)) {
-    ## check if position in position group set
-    cli::cli_abort("Enter valid position group\nOffense: QB, RB, FB, TE, WR,  OL, G, OT, C\nDefense: DB, CB, S, LB, DL, DE, DT, NT\nSpecial Teams: K, P, LS, PK")
-  }
-  if (!is.null(athlete_id) && !is.numeric(athlete_id)) {
-    # Check if athlete_id is numeric, if not NULL
-    cli::cli_abort("Enter valid athlete_id value (Integer)\nCan be found using the `cfbd_player_info()` function")
-  }
-  if (excl_garbage_time != FALSE && excl_garbage_time!=TRUE) {
-    # Check if excl_garbage_time is TRUE, if not FALSE
-    cli::cli_abort("Enter valid excl_garbage_time value (Logical) - TRUE or FALSE")
-  }
 
-  base_url <- "https://api.collegefootballdata.com/player/usage?"
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
+  validate_list(position, pos_groups)
+  validate_id(athlete_id)
+  validate_list(excl_garbage_time, c(T,F))
 
-  # Create full url using base and input arguments
-  full_url <- paste0(
-    base_url,
-    "year=", year,
-    "&team=", team,
-    "&conference=", conference,
-    "&position=", position,
-    "&athleteID=", athlete_id,
-    "&excludeGarbageTime=", excl_garbage_time
+  # Team Name Handling ----
+  team <- handle_accents(team)
+
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/player/usage"
+  query_params <- list(
+    "year" = year,
+    "team" = team,
+    "conference" = conference,
+    "position" = position,
+    "playerId" = athlete_id,
+    "excludeGarbageTime" = excl_garbage_time
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
-
-  # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
-  check_status(res)
-
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
+
+      # Create the GET request and set response as res
+      res <- get_req(full_url)
+      check_status(res)
+
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
@@ -395,15 +323,15 @@ cfbd_player_usage <- function(year = 2019,
         purrr::map_if(is.data.frame, list) %>%
         dplyr::as_tibble() %>%
         dplyr::rename(
-          athlete_id = .data$id,
-          usg_overall = .data$usage.overall,
-          usg_pass = .data$usage.pass,
-          usg_rush = .data$usage.rush,
-          usg_1st_down = .data$usage.firstDown,
-          usg_2nd_down = .data$usage.secondDown,
-          usg_3rd_down = .data$usage.thirdDown,
-          usg_standard_downs = .data$usage.standardDowns,
-          usg_passing_downs = .data$usage.passingDowns
+          "athlete_id" = "id",
+          "usg_overall" = "usage.overall",
+          "usg_pass" = "usage.pass",
+          "usg_rush" = "usage.rush",
+          "usg_1st_down" = "usage.firstDown",
+          "usg_2nd_down" = "usage.secondDown",
+          "usg_3rd_down" = "usage.thirdDown",
+          "usg_standard_downs" = "usage.standardDowns",
+          "usg_passing_downs" = "usage.passingDowns"
         )
 
 
@@ -413,8 +341,6 @@ cfbd_player_usage <- function(year = 2019,
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments or no player usage data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
