@@ -66,25 +66,23 @@ NULL
 #' @importFrom httr GET
 #' @importFrom glue glue
 #' @importFrom dplyr rename
+#' @family CFBD Stats
 #' @export
 #'
 cfbd_stats_categories <- function() {
-  full_url <- "https://api.collegefootballdata.com/stats/categories"
 
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  # Validation ----
+  validate_api_key()
+
+  # Query API ----
+  full_url <- "https://api.collegefootballdata.com/stats/categories"
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as list
@@ -92,7 +90,7 @@ cfbd_stats_categories <- function() {
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON()
       df <- as.data.frame(matrix(unlist(list), nrow = length(list), byrow = TRUE)) %>%
-        dplyr::rename(category = .data$V1)
+        dplyr::rename("category" = "V1")
 
 
       df <- df %>%
@@ -101,8 +99,6 @@ cfbd_stats_categories <- function() {
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments or no stats categories data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -116,11 +112,12 @@ cfbd_stats_categories <- function() {
 #' @param team (*String* optional): D-I Team
 #' @param opponent (*String* optional): Opponent D-I Team
 #' @param excl_garbage_time (*Logical* default FALSE): Select whether to exclude Garbage Time (TRUE/FALSE)
-#' @param season_type (*String* default both): Select Season Type: regular, postseason, or both.
+#' @param season_type (*String* default both): Season type - regular, postseason, both, allstar, spring_regular, spring_postseason
 #'
 #' @return [cfbd_stats_game_advanced()] - A data frame with 60 variables:
 #' \describe{
 #'   \item{`game_id`: integer.}{Referencing game id.}
+#'   \item{`season`: integer.}{Season of the game.}
 #'   \item{`week`: integer.}{Game week of the season.}
 #'   \item{`team`: character.}{Team name.}
 #'   \item{`opponent`: character.}{Opponent team name.}
@@ -184,9 +181,10 @@ cfbd_stats_categories <- function() {
 #' @keywords Game Advanced Stats
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode URLdecode
+#' @importFrom utils URLdecode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
+#' @family CFBD Stats
 #' @export
 #' @examples
 #' \donttest{
@@ -204,72 +202,42 @@ cfbd_stats_game_advanced <- function(year,
                                      excl_garbage_time = FALSE,
                                      season_type = "both") {
 
-  if(!is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
-  if (!is.null(week) && !is.numeric(week) && nchar(week) > 2) {
-    # Check if week is numeric, if not NULL
-    cli::cli_abort("Enter valid week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
+  validate_week(week)
+  validate_list(excl_garbage_time, c(T,F))
+  validate_season_type(season_type)
 
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
-  if (!is.null(opponent)) {
-    # Encode opponent parameter for URL, if not NULL
-    opponent <- utils::URLencode(opponent, reserved = TRUE)
-  }
-  if (excl_garbage_time != FALSE && excl_garbage_time!=TRUE) {
-    # Check if excl_garbage_time is TRUE, if not FALSE
-    cli::cli_abort("Enter valid excl_garbage_time value (Logical) - TRUE or FALSE")
-  }
+  # Team Name Handling ----
+  team <- handle_accents(team)
+  opponent <- handle_accents(opponent)
 
-
-  if (!(season_type %in% c("postseason", "regular","both"))) {
-    # Check if season_type is appropriate, if not NULL
-    cli::cli_abort("Enter valid season_type (String): regular, postseason, or both")
-  }
-
-
-
-
-  base_url <- "https://api.collegefootballdata.com/stats/game/advanced?"
-
-  full_url <- paste0(
-    base_url,
-    "year=", year,
-    "&week=", week,
-    "&team=", team,
-    "&opponent=", opponent,
-    "&excludeGarbageTime=", excl_garbage_time,
-    "&seasonType=", season_type
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/stats/game/advanced"
+  query_params <- list(
+    "year" = year,
+    "week" = week,
+    "team" = team,
+    "opponent" = opponent,
+    "excludeGarbageTime" = excl_garbage_time,
+    "seasonType" = season_type
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content, flatten and return result as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
-        jsonlite::fromJSON(flatten = TRUE)
+        jsonlite::fromJSON(flatten = TRUE) %>%
+        as.data.frame()
 
       # Column renaming for the 76 returned columns
       colnames(df) <- gsub("offense.", "off_", colnames(df))
@@ -306,8 +274,6 @@ cfbd_stats_game_advanced <- function(year,
     error = function(e) {
       message(glue::glue("{Sys.time()}:Invalid arguments or no game advanced stats data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -322,7 +288,7 @@ cfbd_stats_game_advanced <- function(year,
 #' @param start_week (*Integer* optional): Starting Week - values range from 1-15, 1-14 for seasons pre-playoff, i.e. 2013 or earlier
 #' @param end_week (*Integer* optional): Ending Week - values range from 1-15, 1-14 for seasons pre-playoff, i.e. 2013 or earlier
 #'
-#' @return [cfbd_stats_season_advanced()] - A data frame with 81 variables:
+#' @return [cfbd_stats_season_advanced()] - A data frame with 82 variables:
 #' \describe{
 #'   \item{`season`: integer.}{Season of the statistics.}
 #'   \item{`team`: character.}{Team name.}
@@ -409,9 +375,10 @@ cfbd_stats_game_advanced <- function(year,
 #' @keywords Team Season Advanced Stats
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode URLdecode
+#' @importFrom utils URLdecode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
+#' @family CFBD Stats
 #' @export
 #' @examples
 #' \donttest{
@@ -424,67 +391,41 @@ cfbd_stats_season_advanced <- function(year,
                                        start_week = NULL,
                                        end_week = NULL) {
 
-  if(!is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
+  validate_list(excl_garbage_time, c(T,F))
+  validate_week(start_week)
+  validate_week(end_week)
+  validate_range(end_week - start_week, 0)
 
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
-  if (excl_garbage_time != FALSE && excl_garbage_time!=TRUE) {
-    # Check if excl_garbage_time is TRUE, if not FALSE
-    cli::cli_abort("Enter valid excl_garbage_time value (Logical) - TRUE or FALSE")
-  }
-  if (!is.null(start_week) && !is.numeric(start_week) && nchar(start_week) > 2) {
-    # Check if start_week is numeric, if not NULL
-    cli::cli_abort("Enter valid start_week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
-  if (!is.null(end_week) && !is.numeric(end_week) && nchar(end_week) > 2) {
-    # Check if end_week is numeric, if not NULL
-    cli::cli_abort("Enter valid end_week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
-  if (!is.null(start_week) && !is.null(end_week) && start_week > end_week) {
-    cli::cli_abort("Enter valid start_week, end_week range")
-  }
+  # Team Name Handling ----
+  team <- handle_accents(team)
 
-
-
-  base_url <- "https://api.collegefootballdata.com/stats/season/advanced?"
-
-  full_url <- paste0(
-    base_url,
-    "year=", year,
-    "&team=", team,
-    "&excludeGarbageTime=", excl_garbage_time,
-    "&startWeek=", start_week,
-    "&endWeek=", end_week
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/stats/season/advanced"
+  query_params <- list(
+    "year" = year,
+    "team" = team,
+    "excludeGarbageTime" = excl_garbage_time,
+    "startWeek" = start_week,
+    "endWeek" = end_week
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return result as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON(flatten = TRUE)
+
       colnames(df) <- gsub("offense.", "off_", colnames(df))
       colnames(df) <- gsub("defense.", "def_", colnames(df))
       colnames(df) <- gsub("Rate", "_rate", colnames(df))
@@ -519,8 +460,6 @@ cfbd_stats_season_advanced <- function(year,
     error = function(e) {
       message(glue::glue("{Sys.time()}:Invalid arguments or no season advanced stats data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -531,7 +470,7 @@ cfbd_stats_season_advanced <- function(year,
 #' @title
 #' **Get season statistics by player**
 #' @param year (*Integer* required): Year, 4 digit format (*YYYY*)
-#' @param season_type (*String* default: regular): Select Season Type - regular, postseason, or both
+#' @param season_type (*String* default both): Season type - regular, postseason, both, allstar, spring_regular, spring_postseason
 #' @param team (*String* optional): D-I Team
 #' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
 #' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
@@ -545,11 +484,12 @@ cfbd_stats_season_advanced <- function(year,
 #'
 #' @return [cfbd_stats_season_player()] - A data frame with 59 variables:
 #' \describe{
+#'   \item{`year`: integer.}{Season of the player stats.}
 #'   \item{`team`: character.}{Team name.}
 #'   \item{`conference`: character.}{Conference of the team.}
 #'   \item{`athlete_id`: character.}{Athlete referencing id.}
 #'   \item{`player`: character.}{Player name.}
-#'   \item{`category`: character.}{Statistic category.}
+#'   \item{`position`: character.}{Player position.}
 #'   \item{`passing_completions`: double.}{Passing completions.}
 #'   \item{`passing_att`: double.}{Passing attempts.}
 #'   \item{`passing_pct`: double.}{Passing completion percentage.}
@@ -608,12 +548,13 @@ cfbd_stats_season_advanced <- function(year,
 #' @keywords Player Season Stats
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode URLdecode
+#' @importFrom utils URLdecode
 #' @importFrom cli cli_abort
 #' @importFrom janitor clean_names
 #' @importFrom glue glue
-#' @importFrom dplyr mutate mutate_at rename select
-#' @importFrom tidyr pivot_wider everything
+#' @importFrom dplyr mutate mutate_at rename select everything
+#' @importFrom tidyr pivot_wider
+#' @family CFBD Stats
 #' @export
 #'
 #' @examples
@@ -623,82 +564,50 @@ cfbd_stats_season_advanced <- function(year,
 #'    try(cfbd_stats_season_player(2019, team = "LSU", category = "passing"))
 #'
 #'    try(cfbd_stats_season_player(2013, team = "Florida State", category = "passing"))
+#'
 #' }
 
 cfbd_stats_season_player <- function(year,
-                                     season_type = "regular",
+                                     season_type = "both",
                                      team = NULL,
                                      conference = NULL,
                                      start_week = NULL,
                                      end_week = NULL,
                                      category = NULL) {
+
+  # Validation Lists ----
   stat_categories <- c(
     "passing", "receiving", "rushing", "defensive", "fumbles",
     "interceptions", "punting", "puntReturns", "kicking", "kickReturns"
   )
 
-  # Check if year is numeric
-  if(!is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
+  validate_week(start_week)
+  validate_week(end_week)
+  validate_range(end_week - start_week, 0)
+  validate_season_type(season_type)
+  validate_list(category, stat_categories)
 
-  if (!(season_type %in% c("postseason", "regular","both"))) {
-    # Check if season_type is appropriate, if not NULL
-    cli::cli_abort("Enter valid season_type (String): regular, postseason, or both")
-  }
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
-  if (!is.null(conference)) {
-    # # Check conference parameter in conference abbreviations, if not NULL
-    # Encode conference parameter for URL, if not NULL
-    conference <- utils::URLencode(conference, reserved = TRUE)
-  }
+  # Team Name Handling ----
+  team <- handle_accents(team)
 
-  if (!is.null(start_week) && !is.numeric(start_week) && nchar(start_week) > 2) {
-    # Check if start_week is numeric, if not NULL
-    cli::cli_abort("Enter valid start_week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
-  if (!is.null(end_week) && !is.numeric(end_week) && nchar(end_week) > 2) {
-    # Check if end_week is numeric, if not NULL
-    cli::cli_abort("Enter valid end_week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
-  if (!is.null(start_week) && !is.null(end_week) && start_week > end_week) {
-    cli::cli_abort("Enter valid start_week, end_week range")
-  }
-  if (!is.null(category)){
-    if(!(category %in% stat_categories)) {
-      # Check category parameter in category if not NULL
-      cli::cli_abort("Incorrect category, potential misspelling.\nOffense: passing, receiving, rushing\nDefense: defensive, fumbles, interceptions\nSpecial Teams: punting, puntReturns, kicking, kickReturns")
-    }
-    # Encode conference parameter for URL, if not NULL
-    category <- utils::URLencode(category, reserved = TRUE)
-  }
-
-
-  base_url <- "https://api.collegefootballdata.com/stats/player/season?"
-
-  full_url <- paste0(
-    base_url,
-    "year=", year,
-    "&seasonType=", season_type,
-    "&startWeek=", start_week,
-    "&endWeek=", end_week,
-    "&team=", team,
-    "&conference=", conference,
-    "&category=", category
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/stats/player/season"
+  query_params = list(
+    "year" = year,
+    "team" = team,
+    "conference" = conference,
+    "startWeek" = start_week,
+    "endWeek" = end_week,
+    "seasonType" = season_type,
+    "category" = category
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   cols <- c(
-    "team", "conference", "athlete_id", "player", "category",
+    "team", "conference", "athlete_id", "player", "position", "category",
     "passing_completions", "passing_att", "passing_pct", "passing_yds",
     "passing_td", "passing_int", "passing_ypa",
     "rushing_car", "rushing_yds", "rushing_td", "rushing_ypc", "rushing_long",
@@ -736,19 +645,12 @@ cfbd_stats_season_player <- function(year,
     "punt_returns_td", "punt_returns_long"
   )
 
-
-
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return result as data.frame
@@ -759,39 +661,45 @@ cfbd_stats_season_player <- function(year,
           statType = paste0(.data$category, "_", .data$statType)
         ) %>%
         tidyr::pivot_wider(
-          names_from = .data$statType,
-          values_from = .data$stat
+          names_from = "statType",
+          values_from = "stat"
         ) %>%
-        dplyr::rename(athlete_id = .data$playerId) %>%
+        dplyr::rename("athlete_id" = "playerId") %>%
         janitor::clean_names()
 
       df[cols[!(cols %in% colnames(df))]] <- NA
-
+      suppressWarnings(
       df <- df %>%
-        dplyr::select(cols, tidyr::everything()) %>%
+        dplyr::select(dplyr::all_of(cols), dplyr::everything()) %>%
         dplyr::mutate_at(numeric_cols, as.numeric) %>%
-        as.data.frame()
+        as.data.frame() %>%
+        dplyr::mutate(year = year))
 
       # Check if Category is Null
       if (is.null(category)) {
+        suppressWarnings(
         df <- df %>%
-          dplyr::select(-.data$category) %>%
-          dplyr::group_by(.data$team, .data$conference, .data$athlete_id, .data$player, .data$year) %>%
+          dplyr::select(-dplyr::any_of(c("category"))) %>%
+          dplyr::group_by(.data$team, .data$conference, .data$athlete_id, .data$player, .data$position, .data$year) %>%
           dplyr::summarise_all(function(x) mean(x, na.rm = TRUE)) %>%
           dplyr::arrange(.data$year, .data$athlete_id) %>%
           dplyr::ungroup() %>%
-          dplyr::mutate_all(function(x) replace(x, is.nan(x), NA))
+          dplyr::mutate_all(function(x) replace(x, is.nan(x), NA)))
       }
 
 
-      df <- df %>%
+      df <- df  %>%
+        dplyr::select(-dplyr::any_of(c("category"))) %>%
+        dplyr::select(
+          "year", "team", "conference", "athlete_id", "player", "position",
+          dplyr::everything(),
+          -dplyr::any_of("season")
+        ) %>%
         make_cfbfastR_data("Advanced player season stats from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments or no season stats - player data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -801,7 +709,7 @@ cfbd_stats_season_player <- function(year,
 #' @title
 #' **Get season statistics by team**
 #' @param year (*Integer* required): Year, 4 digit format (*YYYY*)
-#' @param season_type (*String* default: regular): Select Season Type - regular, postseason, or both
+#' @param season_type (*String* default: both): Select Season Type - regular, postseason, or both
 #' @param team (*String* optional): D-I Team
 #' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
 #' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC
@@ -861,11 +769,12 @@ cfbd_stats_season_player <- function(year,
 #' @keywords Team Season Stats
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode URLdecode
+#' @importFrom utils URLdecode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
 #' @importFrom dplyr select mutate rename
 #' @importFrom tidyr pivot_wider
+#' @family CFBD Stats
 #' @export
 #'
 #' @examples
@@ -878,65 +787,34 @@ cfbd_stats_season_player <- function(year,
 #' }
 
 cfbd_stats_season_team <- function(year,
-                                   season_type = "regular",
+                                   season_type = "both",
                                    team = NULL,
                                    conference = NULL,
                                    start_week = NULL,
                                    end_week = NULL) {
 
-  # Check if year is numeric
-  if(!is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
+  validate_season_type(season_type)
+  validate_week(start_week)
+  validate_week(end_week)
+  validate_range(end_week - start_week, 0)
 
-  if (!(season_type %in% c("postseason", "regular","both"))) {
-    # Check if season_type is appropriate, if not NULL
-    cli::cli_abort("Enter valid season_type (String): regular, postseason, or both")
-  }
+  # Team Name Handling ----
+  team <- handle_accents(team)
 
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
-  if (!is.null(conference)) {
-    # # Check conference parameter in conference abbreviations, if not NULL
-    # Encode conference parameter for URL, if not NULL
-    conference <- utils::URLencode(conference, reserved = TRUE)
-  }
-
-  if (!is.null(start_week) && !is.numeric(start_week) && nchar(start_week) > 2) {
-    # Check if start_week is numeric, if not NULL
-    cli::cli_abort("Enter valid start_week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
-  if (!is.null(end_week) && !is.numeric(end_week) && nchar(end_week) > 2) {
-    # Check if end_week is numeric, if not NULL
-    cli::cli_abort("Enter valid end_week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
-  if (!is.null(start_week) && !is.null(end_week) && start_week > end_week) {
-    cli::cli_abort("Enter valid start_week, end_week range")
-  }
-
-
-
-
-  base_url <- "https://api.collegefootballdata.com/stats/season?"
-
-  full_url <- paste0(
-    base_url,
-    "year=", year,
-    "&seasonType=", season_type,
-    "&startWeek=", start_week,
-    "&endWeek=", end_week,
-    "&team=", team,
-    "&conference=", conference
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/stats/season"
+  query_params <- list(
+    "year" = year,
+    "seasonType" = season_type,
+    "startWeek" = start_week,
+    "endWeek" = end_week,
+    "team" = team,
+    "conference" = conference
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   # Expected column names for full season data
   expected_colnames <- c(
@@ -953,12 +831,7 @@ cfbd_stats_season_team <- function(year,
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return result as data.frame
@@ -968,8 +841,8 @@ cfbd_stats_season_team <- function(year,
 
       # Pivot category columns to get stats for each team game on one row
       df <- tidyr::pivot_wider(df,
-        names_from = .data$statName,
-        values_from = .data$statValue
+        names_from = "statName",
+        values_from = "statValue"
       )
 
       # Find missing columns, if any, and add them to found data
@@ -994,53 +867,65 @@ cfbd_stats_season_team <- function(year,
         #   punt_return_avg = ifelse(is.na(.data$puntReturns), NA_real_, .data$puntReturnYards / .data$puntReturns)
         # ) %>%
         dplyr::select(
-          .data$season, .data$team, .data$conference,
-          .data$games, .data$possessionTime, #.data$time_of_poss_pg,
-          .data$passCompletions, .data$passAttempts, #.data$completion_pct,
-          .data$netPassingYards, #.data$pass_ypa, .data$pass_ypr,
-          .data$passingTDs, .data$interceptions, #.data$int_pct,
-          .data$rushingAttempts, .data$rushingYards, .data$rushingTDs,
-          #.data$rush_ypc,
-          .data$totalYards,
-          .data$fumblesLost, .data$turnovers, #.data$turnovers_pg,
-          .data$firstDowns, .data$thirdDowns, .data$thirdDownConversions,
-          #.data$third_conv_rate,
-          .data$fourthDownConversions,
-          .data$fourthDowns, #.data$fourth_conv_rate,
-          .data$penalties, .data$penaltyYards, #.data$penalties_pg,
-          #.data$penalty_yds_pg, .data$yards_per_penalty,
-          .data$kickReturns, .data$kickReturnYards,
-          .data$kickReturnTDs, #.data$kick_return_avg,
-          .data$puntReturns, .data$puntReturnYards,
-          .data$puntReturnTDs, #.data$punt_return_avg,
-          .data$passesIntercepted, .data$interceptionYards, .data$interceptionTDs
+          "season",
+          "team",
+          "conference",
+          "games",
+          "possessionTime",
+          "passCompletions",
+          "passAttempts",
+          "netPassingYards",
+          "passingTDs",
+          "interceptions",
+          "rushingAttempts",
+          "rushingYards",
+          "rushingTDs",
+          "totalYards",
+          "fumblesLost",
+          "turnovers",
+          "firstDowns",
+          "thirdDowns",
+          "thirdDownConversions",
+          "fourthDownConversions",
+          "fourthDowns",
+          "penalties",
+          "penaltyYards",
+          "kickReturns",
+          "kickReturnYards",
+          "kickReturnTDs",
+          "puntReturns",
+          "puntReturnYards",
+          "puntReturnTDs",
+          "passesIntercepted",
+          "interceptionYards",
+          "interceptionTDs"
         ) %>%
         dplyr::rename(
-          time_of_poss_total = .data$possessionTime,
-          pass_comps = .data$passCompletions,
-          pass_atts = .data$passAttempts,
-          net_pass_yds = .data$netPassingYards,
-          pass_TDs = .data$passingTDs,
-          rush_atts = .data$rushingAttempts,
-          rush_yds = .data$rushingYards,
-          rush_TDs = .data$rushingTDs,
-          total_yds = .data$totalYards,
-          fumbles_lost = .data$fumblesLost,
-          first_downs = .data$firstDowns,
-          third_downs = .data$thirdDowns,
-          third_down_convs = .data$thirdDownConversions,
-          fourth_downs = .data$fourthDowns,
-          fourth_down_convs = .data$fourthDownConversions,
-          penalty_yds = .data$penaltyYards,
-          kick_returns = .data$kickReturns,
-          kick_return_yds = .data$kickReturnYards,
-          kick_return_TDs = .data$kickReturnTDs,
-          punt_returns = .data$puntReturns,
-          punt_return_yds = .data$puntReturnYards,
-          punt_return_TDs = .data$puntReturnTDs,
-          passes_intercepted = .data$passesIntercepted,
-          passes_intercepted_yds = .data$interceptionYards,
-          passes_intercepted_TDs = .data$interceptionTDs
+          "time_of_poss_total" = "possessionTime",
+          "pass_comps" = "passCompletions",
+          "pass_atts" = "passAttempts",
+          "net_pass_yds" = "netPassingYards",
+          "pass_TDs" = "passingTDs",
+          "rush_atts" = "rushingAttempts",
+          "rush_yds" = "rushingYards",
+          "rush_TDs" = "rushingTDs",
+          "total_yds" = "totalYards",
+          "fumbles_lost" = "fumblesLost",
+          "first_downs" = "firstDowns",
+          "third_downs" = "thirdDowns",
+          "third_down_convs" = "thirdDownConversions",
+          "fourth_downs" = "fourthDowns",
+          "fourth_down_convs" = "fourthDownConversions",
+          "penalty_yds" = "penaltyYards",
+          "kick_returns" = "kickReturns",
+          "kick_return_yds" = "kickReturnYards",
+          "kick_return_TDs" = "kickReturnTDs",
+          "punt_returns" = "puntReturns",
+          "punt_return_yds" = "puntReturnYards",
+          "punt_return_TDs" = "puntReturnTDs",
+          "passes_intercepted" = "passesIntercepted",
+          "passes_intercepted_yds" = "interceptionYards",
+          "passes_intercepted_TDs" = "interceptionTDs"
         )
 
 
@@ -1051,8 +936,6 @@ cfbd_stats_season_team <- function(year,
     error = function(e) {
         message(glue::glue("{Sys.time()}:Invalid arguments or no season team stats data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
