@@ -62,9 +62,10 @@ NULL
 #' @param conference (*String* optional): Conference abbreviation - Select a valid FBS conference
 #' Conference abbreviations P5: ACC, B12, B1G, SEC, PAC,
 #' Conference abbreviations G5 and FBS Independents: CUSA, MAC, MWC, Ind, SBC, AAC
+#' Required if year not provided
 #' @param only_fbs (*Logical* default TRUE): Filter for only returning FBS teams for a given year.
 #' If year is left blank while only_fbs is TRUE, then will return values for most current year
-#' @param year (*Integer* optional): Year, 4 digit format (*YYYY*). Filter for getting a list of major division team for a given year
+#' @param year (*Integer* optional): Year, 4 digit format (*YYYY*). Filter for getting a list of major division team for a given year. Required if conference not provided and the `year` parameter is only supported if `only_fbs` is TRUE.
 #' @return [cfbd_team_info()] - A data frame with 12 variables:
 #' \describe{
 #'   \item{`team_id`: integer.}{Referencing team id.}
@@ -76,6 +77,7 @@ NULL
 #'   \item{`alt_name3`: character.}{Team alternate name 3 (as it appears in `play_text`).}
 #'   \item{`conference`: character.}{Conference of team.}
 #'   \item{`division`: character.}{Division of team within the conference.}
+#'   \item{`classification`: character.}{Conference classification (fbs,fcs,ii,iii)}
 #'   \item{`color`: character.}{Team color (primary).}
 #'   \item{`alt_color`: character.}{Team color (alternate).}
 #'   \item{`logos`: character.}{Team logos.}
@@ -97,9 +99,9 @@ NULL
 #' @keywords Teams
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom dplyr rename
+#' @family CFBD Teams
 #' @export
 #' @examples
 #' \donttest{
@@ -109,55 +111,41 @@ NULL
 #'
 #'   try(cfbd_team_info(year = 2019))
 #' }
-cfbd_team_info <- function(conference = NULL, only_fbs = TRUE, year = NULL) {
+cfbd_team_info <- function(conference = NULL, only_fbs = TRUE, year = most_recent_cfb_season()) {
+
+  # Validation ----
+  validate_api_key()
+  validate_reqs(conference, year)
+  validate_year(year)
+
+  # Query API ----
   if (!is.null(conference)) {
     # # Check conference parameter in conference abbreviations, if not NULL
-    # Encode conference parameter for URL, if not NULL
-    conference <- utils::URLencode(conference, reserved = TRUE)
-
-
-
-    base_url <- "https://api.collegefootballdata.com/teams?"
-
-    full_url <- paste0(
-      base_url,
-      "conference=", conference
-    )
-
-  } else {
-    if(!is.null(year) && !is.numeric(year) && nchar(year) != 4){
-      cli::cli_abort("Enter valid year as a number (YYYY)")
-    }
 
     base_url <- "https://api.collegefootballdata.com/teams"
-
-
-    # if they want all fbs
-    if (only_fbs) {
-      base_url <- paste0(
-        base_url,
-        "/fbs"
-      )
-    }
-    full_url <- paste0(
-      base_url,
-      "?year=", year
+    query_params <- list(
+      "conference" = conference,
+      "year" = year
     )
+    full_url <- httr::modify_url(base_url, query=query_params)
+
+  } else {
+
+    base_url <- "https://api.collegefootballdata.com/teams"
+    if (only_fbs) base_url <- paste0(base_url,"/fbs")
+    query_params <- list(
+      "year" = year
+    )
+    full_url <- httr::modify_url(base_url, query=query_params)
+
   }
 
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
-
+  df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <-get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
@@ -166,8 +154,9 @@ cfbd_team_info <- function(conference = NULL, only_fbs = TRUE, year = NULL) {
         jsonlite::fromJSON()
       locs <- df$location
       locs <- locs %>%
-        jsonlite::flatten()
-      df <- df %>% select(-.data$location)
+        jsonlite::flatten() %>%
+        dplyr::rename("venue_id" = "id")
+      df <- df %>% dplyr::select(-"location")
       # suppressWarnings(
       #   logos_list <- df %>%
       #     dplyr::group_by(.data$id) %>%
@@ -181,12 +170,21 @@ cfbd_team_info <- function(conference = NULL, only_fbs = TRUE, year = NULL) {
       #
       # )
       df <- df %>%
-        tidyr::unnest_wider(.data$logos,names_sep = "_") %>%
-        dplyr::rename(logo = .data$logos_1,logo_2 = .data$logos_2)
+        tidyr::unnest_wider("logos",names_sep = "_") %>%
+        dplyr::rename(
+          "logo" = "logos_1",
+          "logo_2" = "logos_2")
+      df <- df %>%
+        dplyr::rename("alt_name" = "alternateNames") %>%
+        tidyr::unnest_wider("alt_name", names_sep = "")
       df <- dplyr::bind_cols(df, locs) %>%
         dplyr::rename(
-          team_id = .data$id,
-          venue_name = .data$name) %>%
+          "team_id" = "id",
+          "venue_name" = "name",
+          "alt_color" = "alternateColor",
+          "year_constructed" = "constructionYear"
+        ) %>%
+        janitor::clean_names() %>%
         as.data.frame()
 
 
@@ -197,8 +195,6 @@ cfbd_team_info <- function(conference = NULL, only_fbs = TRUE, year = NULL) {
     error = function(e) {
       message(glue::glue("{Sys.time()}:Invalid arguments or no team data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -226,12 +222,11 @@ cfbd_team_info <- function(conference = NULL, only_fbs = TRUE, year = NULL) {
 #' @keywords Team Matchup Records
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
-#' @importFrom tibble enframe
 #' @importFrom dplyr rename mutate select
-#' @importFrom tidyr pivot_wider
+#' @importFrom tibble enframe
+#' @family CFBD Teams
 #' @export
 #' @examples
 #' \donttest{
@@ -242,76 +237,61 @@ cfbd_team_info <- function(conference = NULL, only_fbs = TRUE, year = NULL) {
 #'
 cfbd_team_matchup_records <- function(team1, team2, min_year = NULL, max_year = NULL) {
 
-  if(!is.null(min_year)&& !is.numeric(min_year) && nchar(min_year) != 4){
-    cli::cli_abort("Enter valid min_year as a number (YYYY)")
-  }
-  if(!is.null(max_year)&& !is.numeric(max_year) && nchar(max_year) != 4){
-    cli::cli_abort("Enter valid max_year as a number (YYYY)")
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(min_year)
+  validate_year(max_year)
 
-  if (!is.null(team1)) {
-    if (team1 == "San Jose State") {
-      team1 <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team1 parameter for URL if not NULL
-      team1 <- utils::URLencode(team1, reserved = TRUE)
-    }
-  }
-  if (!is.null(team1)) {
-    if (team2 == "San Jose State") {
-      team2 <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team2 parameter for URL if not NULL
-      team2 <- utils::URLencode(team2, reserved = TRUE)
-    }
-  }
+  # Team Name Handling ----
+  team1 <- handle_accents(team1)
+  team2 <- handle_accents(team2)
 
-  base_url <- "https://api.collegefootballdata.com/teams/matchup?"
-
-  full_url <- paste0(
-    base_url,
-    "team1=", team1,
-    "&team2=", team2,
-    "&minYear=", min_year,
-    "&maxYear=", max_year
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/teams/matchup"
+  query_params <- list(
+    "team1" = team1,
+    "team2" = team2,
+    "minYear" = min_year,
+    "maxYear" = max_year
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  full_url <- httr::modify_url(base_url, query = query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON()
-      df1 <- tibble::enframe(unlist(df, use.names = TRUE))[1:7, ]
-      df <- tidyr::pivot_wider(df1,
-                               names_from = .data$name,
-                               values_from = .data$value
-      ) %>%
+      if (purrr::is_empty(df$games)) stop(call. = F)
+      min_season <- min(df$games$season)
+      max_season <- max(df$games$season)
+      df[['games']] <- NULL
+      df <- df %>%
+        tibble::as_tibble() %>%
+        dplyr::mutate(
+          startYear = ifelse(!is.null(min_year), .data$startYear, min_season),
+          endYear = ifelse(!is.null(max_year), .data$endYear, max_season)
+        ) %>%
         dplyr::rename(
-          start_year = .data$startYear,
-          end_year = .data$endYear,
-          team1_wins = .data$team1Wins,
-          team2_wins = .data$team2Wins
+          "start_year" = "startYear",
+          "end_year" = "endYear",
+          "team1_wins" = "team1Wins",
+          "team2_wins" = "team2Wins"
         ) %>%
         dplyr::select(
-          .data$start_year, .data$end_year,
-          .data$team1, .data$team1_wins,
-          .data$team2, .data$team2_wins,
-          .data$ties
+          "start_year",
+          "end_year",
+          "team1",
+          "team1_wins",
+          "team2",
+          "team2_wins",
+          "ties"
         )
       df <- as.data.frame(df)
 
@@ -354,10 +334,10 @@ cfbd_team_matchup_records <- function(team1, team2, min_year = NULL, max_year =
 #' @keywords Team Matchup
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom janitor clean_names
 #' @importFrom glue glue
+#' @family CFBD Teams
 #' @export
 #' @examples
 #' \donttest{
@@ -372,62 +352,39 @@ cfbd_team_matchup_records <- function(team1, team2, min_year = NULL, max_year =
 #'
 cfbd_team_matchup <- function(team1, team2, min_year = NULL, max_year = NULL) {
 
-  if(!is.null(min_year)&& !is.numeric(min_year) && nchar(min_year) != 4){
-    cli::cli_abort("Enter valid min_year as a number (YYYY)")
-  }
-  if(!is.null(max_year)&& !is.numeric(max_year) && nchar(max_year) != 4){
-    cli::cli_abort("Enter valid max_year as a number (YYYY)")
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(min_year)
+  validate_year(max_year)
 
-  if (!is.null(team1)) {
-    if (team1 == "San Jose State") {
-      team1 <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team1 parameter for URL if not NULL
-      team1 <- utils::URLencode(team1, reserved = TRUE)
-    }
-  }
-  if (!is.null(team1)) {
-    if (team2 == "San Jose State") {
-      team2 <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team2 parameter for URL if not NULL
-      team2 <- utils::URLencode(team2, reserved = TRUE)
-    }
-  }
+  # Team Name Handling ----
+  team1 <- handle_accents(team1)
+  team2 <- handle_accents(team2)
 
-  base_url <- "https://api.collegefootballdata.com/teams/matchup?"
-
-  full_url <- paste0(
-    base_url,
-    "team1=", team1,
-    "&team2=", team2,
-    "&minYear=", min_year,
-    "&maxYear=", max_year
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/teams/matchup"
+  query_params <- list(
+    "team1" = team1,
+    "team2" = team2,
+    "minYear" = min_year,
+    "maxYear" = max_year
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <-get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON() %>%
-        .data$games
-      if (nrow(df) == 0) {
+        purrr::pluck("games")
+      if (is.null(df) || nrow(df) == 0) {
         warning("The data pulled from the API was empty.")
         return(NULL)
       }
@@ -442,8 +399,6 @@ cfbd_team_matchup <- function(team1, team2, min_year = NULL, max_year = NULL) {
     error = function(e) {
       message(glue::glue("{Sys.time()}:Invalid arguments or no team matchup data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -483,9 +438,9 @@ cfbd_team_matchup <- function(team1, team2, min_year = NULL, max_year = NULL) {
 #' @importFrom dplyr rename mutate
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
+#' @family CFBD Teams
 #' @export
 #' @examples
 #' \donttest{
@@ -493,68 +448,49 @@ cfbd_team_matchup <- function(team1, team2, min_year = NULL, max_year = NULL) {
 #' }
 #'
 cfbd_team_roster <- function(year, team = NULL) {
-  team2 <- team
 
-  if(!is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
 
+  # Team Name Handling ----
+  team <- handle_accents(team)
 
-  if (!is.null(team)) {
-    if (team == "San Jose State") {
-      team <- utils::URLencode(paste0("San Jos", "\u00e9", " State"), reserved = TRUE)
-    } else {
-      # Encode team1 parameter for URL if not NULL
-      team <- utils::URLencode(team, reserved = TRUE)
-    }
-  }
-  base_url <- "https://api.collegefootballdata.com/roster?"
-
-  if (is.null(team)) {
-    full_url <- paste0(
-      base_url,
-      "year=", year
-    )
-  } else {
-    full_url <- paste0(
-      base_url, "team=", team,
-      "&year=", year
-    )
-  }
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/roster"
+  query_params <- list(
+    "year" = year,
+    "team" = team
+  )
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
       df <- res %>%
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON() %>%
-        dplyr::rename(athlete_id = .data$id) %>%
-        dplyr::mutate(headshot_url = paste0("https://a.espncdn.com/i/headshots/college-football/players/full/",.data$athlete_id,".png")) %>%
+        dplyr::rename("athlete_id" = "id") %>%
+        dplyr::mutate(
+          headshot_url = paste0("https://a.espncdn.com/i/headshots/college-football/players/full/",.data$athlete_id,".png")) %>%
         as.data.frame()
-
+      df$recruitIds <- lapply(df$recruitIds, function(y){
+        if(length(y) == 0) as.integer(0) else y
+      })
 
       df <- df %>%
+        janitor::clean_names() %>%
         make_cfbfastR_data("Team roster data from CollegeFootballData.com",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}:Invalid arguments or no team roster data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -577,9 +513,9 @@ cfbd_team_roster <- function(year, team = NULL) {
 #' @keywords Team talent
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
-#' @importFrom utils URLencode
 #' @importFrom cli cli_abort
 #' @importFrom glue glue
+#' @family CFBD Teams
 #' @export
 #' @examples
 #' \donttest{
@@ -588,33 +524,25 @@ cfbd_team_roster <- function(year, team = NULL) {
 #'   try(cfbd_team_talent(year = 2018))
 #' }
 #'
-cfbd_team_talent <- function(year = NULL) {
-  if(!is.null(year) && !is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
+cfbd_team_talent <- function(year = most_recent_cfb_season()) {
 
-  base_url <- "https://api.collegefootballdata.com/talent?"
+  # Validation ----
+  validate_api_key()
+  validate_year(year)
 
-  full_url <- paste0(
-    base_url,
-    "year=", year
+  # Query API ----
+  base_url <- "https://api.collegefootballdata.com/talent"
+  query_params <- list(
+    "year" = year
   )
-
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
-
+  full_url <- httr::modify_url(base_url, query=query_params)
 
   df <- data.frame()
   tryCatch(
     expr = {
 
       # Create the GET request and set response as res
-      res <- httr::RETRY(
-        "GET", full_url,
-        httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-      )
-
-      # Check the result
+      res <- get_req(full_url)
       check_status(res)
 
       # Get the content and return it as data.frame
@@ -622,7 +550,8 @@ cfbd_team_talent <- function(year = NULL) {
         httr::content(as = "text", encoding = "UTF-8") %>%
         jsonlite::fromJSON() %>%
         as.data.frame() %>%
-        mutate(talent = as.numeric(.data$talent))
+        dplyr::mutate(talent = as.numeric(.data$talent)) %>%
+        dplyr::rename("school" = "team")
 
 
       df <- df %>%
@@ -631,8 +560,6 @@ cfbd_team_talent <- function(year = NULL) {
     error = function(e) {
       message(glue::glue("{Sys.time()}:Invalid arguments or no team talent data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
