@@ -16,7 +16,8 @@
 #'   \item{`state`:character.}{Venue state.}
 #'   \item{`zip`:character.}{Venue zip.}
 #'   \item{`country_code`:character.}{Venue country code.}
-#'   \item{`location`:list.}{Venue location.}
+#'   \item{`latitude`:double.}{Venue latitude.}
+#'   \item{`longitude`: double.}{Venue longitude.}
 #'   \item{`elevation`:character.}{Venue elevation.}
 #'   \item{`year_constructed`:integer.}{Year in which the venue was constructed.}
 #'   \item{`dome`:logical.}{TRUE/FALSE response to whether the venue has a dome or not.}
@@ -26,6 +27,7 @@
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET
 #' @importFrom dplyr rename
+#' @family CFBD Venues
 #' @examples
 #' \donttest{
 #'   try(cfbd_venues())
@@ -33,25 +35,26 @@
 #' @export
 
 cfbd_venues <- function() {
+
+  # Validation ----
+  validate_api_key()
+
+  # Query API ----
   full_url <- "https://api.collegefootballdata.com/venues"
 
-  # Check for CFBD API key
-  if (!has_cfbd_key()) stop("CollegeFootballData.com now requires an API key.", "\n       See ?register_cfbd for details.", call. = FALSE)
-
   # Create the GET request and set response as res
-  res <- httr::RETRY(
-    "GET", full_url,
-    httr::add_headers(Authorization = paste("Bearer", cfbd_key()))
-  )
-
-  # Check the result
+  res <- get_req(full_url)
   check_status(res)
 
   # Get the content and return it as data.frame
   df <- res %>%
     httr::content(as = "text", encoding = "UTF-8") %>%
     jsonlite::fromJSON() %>%
-    dplyr::rename(venue_id = .data$id) %>%
+    dplyr::rename(
+      "venue_id" = "id",
+      "year_constructed" = "constructionYear",
+      "country_code" = "countryCode"
+    ) %>%
     as.data.frame()
 
 
