@@ -4,9 +4,9 @@
 #' **Create EPA**
 #' @description Adds Expected Points calculations to Play-by-Play data.frame
 #'
-#' @param clean_pbp_dat (*data.frame* required): Clean PBP as input from [cfbd_pbp_data()]
-#' @param ep_model (*model* default ```cfbfastR```'s `ep_model`): Expected Points (EP) Model
-#' @param fg_model (*model* default ```cfbfastR```'s `fg_model`): Field Goal (FG) Model
+#' @param play_df (*data.frame* required): Clean PBP as input from [cfbd_pbp_data()]
+#' @param ep_model (*model* default `cfbfastR`'s `ep_model`): Expected Points (EP) Model
+#' @param fg_model (*model* default `cfbfastR`'s `fg_model`): Field Goal (FG) Model
 #' @details Code Description
 #' \describe{
 #'   \item{1. `pred_df`:}{Use select before play model variables -> Make predictions.}
@@ -16,6 +16,7 @@
 #'   \item{5. `kickoffs`:}{Calculate ep_before for kickoffs as if the pre-play assumption is a touchback.}
 #'   \item{6. `wpa_prep`:}{Prep variables for WPA.}
 #' }
+#' @return play_df with  EPA variables added
 #' @keywords internal
 #' @importFrom stats na.omit
 #' @importFrom stats predict
@@ -50,18 +51,18 @@ create_epa <- function(play_df,
   # get before play expected points model variables
   pred_df <- clean_pbp %>%
     dplyr::select(
-      .data$id_play,
-      .data$drive_id,
-      .data$game_id,
-      .data$play_type,
-      .data$TimeSecsRem,
-      .data$down,
-      .data$distance,
-      .data$yards_to_goal,
-      .data$log_ydstogo,
-      .data$Under_two,
-      .data$Goal_To_Go,
-      .data$pos_score_diff_start
+      "id_play",
+      "drive_id",
+      "game_id",
+      "play_type",
+      "TimeSecsRem",
+      "down",
+      "distance",
+      "yards_to_goal",
+      "log_ydstogo",
+      "Under_two",
+      "Goal_To_Go",
+      "pos_score_diff_start"
     ) %>%
     dplyr::filter(.data$down > 0) %>%
     dplyr::mutate(down = as.factor(.data$down))
@@ -69,19 +70,19 @@ create_epa <- function(play_df,
   # get after play expected points model variables
   pred_df_after <- clean_pbp %>%
     dplyr::select(
-      .data$id_play,
-      .data$drive_id,
-      .data$game_id,
-      .data$play_type,
-      .data$turnover,
-      .data$new_TimeSecsRem,
-      .data$new_down,
-      .data$new_distance,
-      .data$new_yardline,
-      .data$new_log_ydstogo,
-      .data$new_Under_two,
-      .data$new_Goal_To_Go,
-      .data$new_pos_score_diff_start
+      "id_play",
+      "drive_id",
+      "game_id",
+      "play_type",
+      "turnover",
+      "new_TimeSecsRem",
+      "new_down",
+      "new_distance",
+      "new_yardline",
+      "new_log_ydstogo",
+      "new_Under_two",
+      "new_Goal_To_Go",
+      "new_pos_score_diff_start"
     ) %>%
     dplyr::mutate(new_down = as.numeric(.data$new_down)) %>%
     dplyr::filter(.data$new_down > 0) %>%
@@ -296,20 +297,29 @@ create_epa <- function(play_df,
   pred_df <- play_df %>%
     dplyr::left_join(
       pred_df_after %>%
-        dplyr::select(-.data$play_type, -.data$turnover),
+        dplyr::select(-"play_type", -"turnover"),
       by = c("game_id", "drive_id", "id_play")
     ) %>%
     dplyr::left_join(
-      pred_df %>% select(-.data$play_type) %>%
+      pred_df %>% select(-"play_type") %>%
         dplyr::select(
-          .data$id_play, .data$drive_id, .data$game_id,
-          .data$No_Score_before, .data$FG_before,
-          .data$Opp_FG_before, .data$Opp_Safety_before,
-          .data$Opp_TD_before, .data$Safety_before,
-          .data$TD_before, .data$ep_before, .data$fg_make_prob,
-          .data$lag_ep_before3, .data$lag_ep_before2,
-          .data$lag_ep_before, .data$lead_ep_before,
-          .data$lead_ep_before2
+          "id_play",
+          "drive_id",
+          "game_id",
+          "No_Score_before",
+          "FG_before",
+          "Opp_FG_before",
+          "Opp_Safety_before",
+          "Opp_TD_before",
+          "Safety_before",
+          "TD_before",
+          "ep_before",
+          "fg_make_prob",
+          "lag_ep_before3",
+          "lag_ep_before2",
+          "lag_ep_before",
+          "lead_ep_before",
+          "lead_ep_before2"
         ),
       by = c("game_id", "drive_id", "id_play")
     )
@@ -374,71 +384,71 @@ create_epa <- function(play_df,
       ExpScoreDiff_Time_Ratio = .data$ExpScoreDiff / (.data$adj_TimeSecsRem + 1)
     ) %>%
     dplyr::select(
-      -.data$new_TimeSecsRem,
-      -.data$new_down,
-      -.data$new_distance,
-      -.data$new_yardline,
-      -.data$new_log_ydstogo,
-      -.data$new_Under_two,
-      -.data$new_Goal_To_Go,
-      -.data$new_pos_score_diff_start
+      -"new_TimeSecsRem",
+      -"new_down",
+      -"new_distance",
+      -"new_yardline",
+      -"new_log_ydstogo",
+      -"new_Under_two",
+      -"new_Goal_To_Go",
+      -"new_pos_score_diff_start"
     ) %>%
     dplyr::select(
-      .data$game_id,
-      .data$id_play,
-      .data$drive_id,
-      .data$home,
-      .data$away,
-      .data$drive_number,
-      .data$drive_play_number,
-      .data$game_play_number,
-      .data$pos_team,
-      .data$def_pos_team,
-      .data$clock.minutes,
-      .data$clock.seconds,
-      .data$half,
-      .data$period,
-      .data$TimeSecsRem,
-      .data$play_type,
-      .data$play_text,
-      .data$down,
-      .data$distance,
-      .data$yards_to_goal,
-      .data$yards_gained,
-      .data$Goal_To_Go,
-      .data$Under_two,
-      .data$pos_score_diff,
-      .data$pos_score_diff_start,
-      .data$pos_team_score,
-      .data$def_pos_team_score,
-      .data$ep_before,
-      .data$ep_after,
-      .data$EPA,
-      .data$def_EPA,
-      .data$pos_team_timeouts_rem_before,
-      .data$def_pos_team_timeouts_rem_before,
-      .data$offense_timeouts,
-      .data$defense_timeouts,
-      .data$down_end,
-      .data$distance_end,
-      .data$yards_to_goal_end,
-      .data$TimeSecsRem_end,
-      .data$log_ydstogo_end,
-      .data$Goal_To_Go_end,
-      .data$Under_two_end,
-      .data$score_diff,
-      .data$score_diff_start,
-      .data$ppa,
-      .data$drive_start_yards_to_goal,
-      .data$drive_end_yards_to_goal,
-      .data$drive_yards,
-      .data$drive_scoring,
-      .data$drive_result_detailed,
-      .data$new_drive_pts,
-      .data$offense_play,
-      .data$defense_play,
-      .data$offense_score,
-      .data$defense_score,
+      "game_id",
+      "id_play",
+      "drive_id",
+      "home",
+      "away",
+      "drive_number",
+      "drive_play_number",
+      "game_play_number",
+      "pos_team",
+      "def_pos_team",
+      "clock_minutes",
+      "clock_seconds",
+      "half",
+      "period",
+      "TimeSecsRem",
+      "play_type",
+      "play_text",
+      "down",
+      "distance",
+      "yards_to_goal",
+      "yards_gained",
+      "Goal_To_Go",
+      "Under_two",
+      "pos_score_diff",
+      "pos_score_diff_start",
+      "pos_team_score",
+      "def_pos_team_score",
+      "ep_before",
+      "ep_after",
+      "EPA",
+      "def_EPA",
+      "pos_team_timeouts_rem_before",
+      "def_pos_team_timeouts_rem_before",
+      "offense_timeouts",
+      "defense_timeouts",
+      "down_end",
+      "distance_end",
+      "yards_to_goal_end",
+      "TimeSecsRem_end",
+      "log_ydstogo_end",
+      "Goal_To_Go_end",
+      "Under_two_end",
+      "score_diff",
+      "score_diff_start",
+      "ppa",
+      "drive_start_yards_to_goal",
+      "drive_end_yards_to_goal",
+      "drive_yards",
+      "drive_scoring",
+      "drive_result_detailed",
+      "new_drive_pts",
+      "offense_play",
+      "defense_play",
+      "offense_score",
+      "defense_score",
       dplyr::everything()
     ) %>%
     dplyr::mutate(
@@ -462,11 +472,12 @@ create_epa <- function(play_df,
 }
 
 #' @rdname create_epa
-#' @param df (__data.frame__ required): Clean Play-By-Play data.frame as can be pulled from [clean_pbp_dat()]
+#' @param dat (__data.frame__ required): Clean Play-By-Play data.frame as can be pulled from [clean_pbp_dat()]
 #' @param current_probs (__data.frame__ required): Expected Points (EP) model raw probability outputs from initial prediction
-#' @param ep_model (__model__, default ```cfbfastR```'s `ep_model`): FG Model to be used for prediction on field goal (FG) attempts in Play-by-Play data.frame
-#' @param fg_mod (__model__, default ```cfbfastR```'s `fg_model`): FG Model to be used for prediction on field goal (FG) attempts in Play-by-Play data.frame
+#' @param ep_model (__model__, default `cfbfastR`'s `ep_model`): FG Model to be used for prediction on field goal (FG) attempts in Play-by-Play data.frame
+#' @param fg_mod (__model__, default `cfbfastR`'s `fg_model`): FG Model to be used for prediction on field goal (FG) attempts in Play-by-Play data.frame
 #'
+#' @return Updated expected points probabilities with FG make/miss weighted adjustment
 #' @keywords internal
 #' @importFrom mgcv predict.bam
 #' @importFrom stringr str_detect
