@@ -18,6 +18,7 @@ NULL
 #'   \item{`game_uid`: character.}{}
 #'   \item{`game_date`: character.}{Game date.}
 #'   \item{`attendance`: integer.}{Reported attendance at the game.}
+#'   \item{`play_by_play_available`: logical}{}
 #'   \item{`home_team_name`: character.}{Home team mascot name (Sun Devils).}
 #'   \item{`home_team_logo`: character.}{Home team logo url.}
 #'   \item{`home_team_abb`: character.}{Home team abbreviation (ASU).}
@@ -106,19 +107,36 @@ espn_cfb_scoreboard <- function(date = NULL) {
 
       cfb_data <- raw_sched[["events"]] %>%
         tibble::tibble(data = .data$.) %>%
-        tidyr::unnest_wider(.data$data) %>%
-        tidyr::unchop(.data$competitions) %>%
-        dplyr::select(-.data$id, -.data$uid, -.data$date, -.data$status) %>%
-        tidyr::unnest_wider(.data$competitions) %>%
-        dplyr::rename(matchup = .data$name, matchup_short = .data$shortName, game_id = .data$id, game_uid = .data$uid, game_date = .data$date) %>%
-        tidyr::hoist(.data$status,
+        tidyr::unnest_wider("data") %>%
+        tidyr::unchop("competitions") %>%
+        dplyr::select(
+          -"id",
+          -"uid",
+          -"date",
+          -"status") %>%
+        tidyr::unnest_wider("competitions") %>%
+        dplyr::rename(
+          "matchup" = "name",
+          "matchup_short" = "shortName",
+          "game_id" = "id",
+          "game_uid" = "uid",
+          "game_date" = "date") %>%
+        tidyr::hoist("status",
                      status_name = list("type", "name")) %>%
         dplyr::select(!dplyr::any_of(c("timeValid", "neutralSite", "conferenceCompetition","recent", "venue", "type"))) %>%
-        tidyr::unnest_wider(.data$season) %>%
-        dplyr::rename(season = .data$year) %>%
-        dplyr::select(-dplyr::any_of("status")) %>%
+        tidyr::unnest_wider("season") %>%
+        dplyr::rename("season" = "year") %>%
+        dplyr::select(-dplyr::any_of("status"))
+
+      cfb_data <- cfb_data %>%
+        dplyr::mutate(
+          game_date_time = lubridate::ymd_hm(substr(.data$game_date, 1, nchar(.data$game_date) - 1)) %>%
+            lubridate::with_tz(tzone = "America/New_York"),
+          game_date = as.Date(substr(.data$game_date_time, 1, 10)))
+
+      cfb_data <- cfb_data %>%
         tidyr::hoist(
-          .data$competitors,
+          "competitors",
           home_team_name = list(1, "team", "name"),
           home_team_logo = list(1, "team", "logo"),
           home_team_abb = list(1, "team", "abbreviation"),
@@ -145,15 +163,15 @@ espn_cfb_scoreboard <- function(date = NULL) {
                       away_win = as.integer(.data$away_win),
                       home_score = as.integer(.data$home_score),
                       away_score = as.integer(.data$away_score),
-                      type = case_when(type == 2 ~ "regular",
+                      type = dplyr::case_when(type == 2 ~ "regular",
                                        type == 3 ~ "postseason",
                                        type == 4 ~ "off-season",
                                        TRUE ~ as.character(type)))
 
-      if("leaders" %in% names(cfb_data)){
+      if ("leaders" %in% names(cfb_data)) {
         schedule_out <- cfb_data %>%
           tidyr::hoist(
-            .data$leaders,
+            "leaders",
             # passing
             passing_leader_yards = list(1, "leaders", 1, "value"),
             passing_leader_stat = list(1, "leaders", 1, "displayValue"),
@@ -180,10 +198,10 @@ espn_cfb_scoreboard <- function(date = NULL) {
             receiving_leader_pos = list(3, "leaders", 1, "athlete", "position", "abbreviation")
           )
 
-        if("broadcasts" %in% names(schedule_out)) {
+        if ("broadcasts" %in% names(schedule_out)) {
           schedule_out <- schedule_out %>%
             tidyr::hoist(
-              .data$broadcasts,
+              "broadcasts",
               broadcast_market = list(1, "market"),
               broadcast_name = list(1, "names", 1)
             ) %>%
@@ -194,17 +212,21 @@ espn_cfb_scoreboard <- function(date = NULL) {
             janitor::clean_names()
         }
       } else {
-        schedule_out <- cfb_data %>% dplyr::select(!where(is.list)) %>%
+        schedule_out <- cfb_data %>%
+          dplyr::select(!where(is.list)) %>%
           janitor::clean_names()
       }
+      if (!"highlights" %in% names(schedule_out)) {
+        schedule_out <-
+          schedule_out %>%
+          dplyr::mutate(highlights = NA)
+      }
       schedule_out %>%
         make_cfbfastR_data("Live Scoreboard Data from ESPN",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}: Invalid arguments or no ESPN scoreboard data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -217,6 +239,45 @@ espn_cfb_scoreboard <- function(date = NULL) {
 #' @param groups (string): Used to define different divisions. FBS or FCS.
 #' @param season_type (string): "regular", "postseason", "off-season", or "both".
 #' @param limit (int): number of records to return, default: 500.
+#'
+#' @return [espn_cfb_schedule()] - A data frame with 8 variables:
+#' \describe{
+#'   \item{`matchup`: character.}{.}
+#'   \item{`matchup_short`: character.}{.}
+#'   \item{`season`: integer.}{.}
+#'   \item{`type`: character.}{.}
+#'   \item{`slug`: character.}{.}
+#'   \item{`game_id`: character.}{.}
+#'   \item{`game_uid`: character.}{.}
+#'   \item{`game_date`: Date.}{.}
+#'   \item{`attendance`: integer.}{.}
+#'   \item{`date_valid`: logical.}{.}
+#'   \item{`play_by_play_available`: logical.}{.}
+#'   \item{`home_team_name`: character.}{.}
+#'   \item{`home_team_logo`: character.}{.}
+#'   \item{`home_team_abb`: character.}{.}
+#'   \item{`home_team_id`: character.}{.}
+#'   \item{`home_team_location`: character.}{.}
+#'   \item{`home_team_full`: character.}{.}
+#'   \item{`home_team_color`: character.}{.}
+#'   \item{`home_score`: integer.}{.}
+#'   \item{`home_win`: integer.}{.}
+#'   \item{`home_record`: character.}{.}
+#'   \item{`away_team_name`: character.}{.}
+#'   \item{`away_team_logo`: character.}{.}
+#'   \item{`away_team_abb`: character.}{.}
+#'   \item{`away_team_id`: character.}{.}
+#'   \item{`away_team_location`: character.}{.}
+#'   \item{`away_team_full`: character.}{.}
+#'   \item{`away_team_color`: character.}{.}
+#'   \item{`away_score`: integer.}{.}
+#'   \item{`away_win`: integer.}{.}
+#'   \item{`away_record`: character.}{.}
+#'   \item{`status_name`: character.}{.}
+#'   \item{`start_date`: character.}{.}
+#'   \item{`highlights`: logical.}{.}
+#'   \item{`game_date_time`: datetime.}{.}
+#' }
 #' @keywords Schedule Data
 #' @importFrom jsonlite fromJSON
 #' @importFrom httr GET RETRY
@@ -224,6 +285,7 @@ espn_cfb_scoreboard <- function(date = NULL) {
 #' @importFrom cli cli_abort
 #' @importFrom janitor clean_names
 #' @importFrom stringr str_sub str_length
+#' @importFrom lubridate ymd_hm with_tz
 #' @import dplyr
 #' @export
 #' @examples
@@ -233,25 +295,20 @@ espn_cfb_scoreboard <- function(date = NULL) {
 
 espn_cfb_schedule <- function(year=NULL, week=NULL, season_type=NULL, groups=NULL, limit=500){
 
-  if(!is.null(year) && !is.numeric(year) && nchar(year) != 4){
-    cli::cli_abort("Enter valid year as a number (YYYY)")
-  }
-  if (!is.null(week) && !is.numeric(week) && nchar(week) > 2) {
-    # Check if week is numeric, if not NULL
-    cli::cli_abort("Enter valid week 1-15\n(14 for seasons pre-playoff, i.e. 2014 or earlier)")
-  }
+  validate_year(year)
+  validate_week(week)
 
-  if(is.null(week)){
+  if (is.null(week)) {
     week = ''
   } else {
     week = paste0('&week=',week)
   }
-  if(is.null(year)) {
+  if (is.null(year)) {
     year <- ''
   } else {
     year <- paste0('&dates=',year)
   }
-  if(is.null(season_type)) {
+  if (is.null(season_type)) {
     season_type <- ''
   } else {
     if (season_type %in% c("regular","postseason","off-season","both")) {
@@ -266,7 +323,7 @@ espn_cfb_schedule <- function(year=NULL, week=NULL, season_type=NULL, groups=NUL
     }
     season_type <- paste0('&seasontype=',season_type)
   }
-  if(is.null(groups)) {
+  if (is.null(groups)) {
     groups <- '&groups=80'
   } else {
     if (tolower(groups) %in% c("fbs","fcs")) {
@@ -295,19 +352,36 @@ espn_cfb_schedule <- function(year=NULL, week=NULL, season_type=NULL, groups=NUL
 
       cfb_data <- raw_sched[["events"]] %>%
         tibble::tibble(data = .data$.) %>%
-        tidyr::unnest_wider(.data$data) %>%
-        tidyr::unchop(.data$competitions) %>%
-        dplyr::select(-.data$id, -.data$uid, -.data$date, -.data$status) %>%
-        tidyr::unnest_wider(.data$competitions) %>%
-        dplyr::rename(matchup = .data$name, matchup_short = .data$shortName, game_id = .data$id, game_uid = .data$uid, game_date = .data$date) %>%
-        tidyr::hoist(.data$status,
+        tidyr::unnest_wider("data") %>%
+        tidyr::unchop("competitions") %>%
+        dplyr::select(
+          -"id",
+          -"uid",
+          -"date",
+          -"status") %>%
+        tidyr::unnest_wider("competitions") %>%
+        dplyr::rename(
+          "matchup" = "name",
+          "matchup_short" = "shortName",
+          "game_id" = "id",
+          "game_uid" = "uid",
+          "game_date" = "date") %>%
+        tidyr::hoist("status",
                      status_name = list("type", "name")) %>%
         dplyr::select(!dplyr::any_of(c("timeValid", "neutralSite", "conferenceCompetition","recent", "venue", "type"))) %>%
-        tidyr::unnest_wider(.data$season) %>%
-        dplyr::rename(season = .data$year) %>%
-        dplyr::select(-dplyr::any_of("status")) %>%
+        tidyr::unnest_wider("season") %>%
+        dplyr::rename("season" = "year") %>%
+        dplyr::select(-dplyr::any_of("status"))
+
+      cfb_data <- cfb_data %>%
+        dplyr::mutate(
+          game_date_time = lubridate::ymd_hm(substr(.data$game_date, 1, nchar(.data$game_date) - 1)) %>%
+            lubridate::with_tz(tzone = "America/New_York"),
+          game_date = as.Date(substr(.data$game_date_time, 1, 10)))
+
+      cfb_data <- cfb_data %>%
         tidyr::hoist(
-          .data$competitors,
+          "competitors",
           home_team_name = list(1, "team", "name"),
           home_team_logo = list(1, "team", "logo"),
           home_team_abb = list(1, "team", "abbreviation"),
@@ -334,15 +408,16 @@ espn_cfb_schedule <- function(year=NULL, week=NULL, season_type=NULL, groups=NUL
                       away_win = as.integer(.data$away_win),
                       home_score = as.integer(.data$home_score),
                       away_score = as.integer(.data$away_score),
-                      type = case_when(type == 2 ~ "regular",
+                      type = dplyr::case_when(type == 2 ~ "regular",
                                        type == 3 ~ "postseason",
                                        type == 4 ~ "off-season",
                                        TRUE ~ as.character(type)))
 
+
       if("leaders" %in% names(cfb_data)){
         schedule_out <- cfb_data %>%
           tidyr::hoist(
-            .data$leaders,
+            "leaders",
             # passing
             passing_leader_yards = list(1, "leaders", 1, "value"),
             passing_leader_stat = list(1, "leaders", 1, "displayValue"),
@@ -372,7 +447,7 @@ espn_cfb_schedule <- function(year=NULL, week=NULL, season_type=NULL, groups=NUL
         if("broadcasts" %in% names(schedule_out)) {
           schedule_out <- schedule_out %>%
             tidyr::hoist(
-              .data$broadcasts,
+              "broadcasts",
               broadcast_market = list(1, "market"),
               broadcast_name = list(1, "names", 1)
             ) %>%
@@ -383,17 +458,22 @@ espn_cfb_schedule <- function(year=NULL, week=NULL, season_type=NULL, groups=NUL
             janitor::clean_names()
         }
       } else {
-        schedule_out <- cfb_data %>% dplyr::select(!where(is.list)) %>%
+        schedule_out <- cfb_data %>%
+          dplyr::select(!where(is.list)) %>%
           janitor::clean_names()
       }
-      schedule_out <- schedule_out %>%
+      if (!"highlights" %in% names(schedule_out)) {
+        schedule_out <-
+          schedule_out %>%
+          dplyr::mutate(highlights = NA)
+      }
+      schedule_out <-
+        schedule_out %>%
         make_cfbfastR_data("Schedule Data from ESPN",Sys.time())
     },
     error = function(e) {
       message(glue::glue("{Sys.time()}: invalid input or no ESPN schedule data available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
@@ -466,19 +546,22 @@ espn_cfb_calendar <- function(year=NULL, groups=NULL){
 
       calendar_out <- raw_cal[["leagues"]] %>%
         tibble::tibble(data = .data$.) %>%
-        tidyr::unnest_wider(.data$data) %>%
-        tidyr::unnest(.data$calendar) %>%
-        tidyr::unnest_wider(.data$calendar) %>%
-        tidyr::unnest(.data$entries) %>%
-        dplyr::rename(season_type = .data$label)
+        tidyr::unnest_wider("data") %>%
+        tidyr::unnest("calendar") %>%
+        tidyr::unnest_wider("calendar") %>%
+        tidyr::unnest("entries") %>%
+        dplyr::rename("season_type" = "label")
 
       calendar_out$season <- substr(calendar_out$calendarStartDate[1],1,4)
 
       calendar_out <- calendar_out %>%
-        dplyr::select(.data$season,.data$season_type,.data$entries) %>%
-        tidyr::unnest_wider(.data$entries) %>%
+        dplyr::select(
+          "season",
+          "season_type",
+          "entries") %>%
+        tidyr::unnest_wider("entries") %>%
         janitor::clean_names() %>%
-        dplyr::rename(week = .data$value)
+        dplyr::rename("week" = "value")
 
       calendar_out <- calendar_out %>%
         make_cfbfastR_data("Calendar Data from ESPN",Sys.time())
@@ -486,8 +569,6 @@ espn_cfb_calendar <- function(year=NULL, groups=NULL){
     error = function(e) {
       message(glue::glue("{Sys.time()}: invalid input or no ESPN calendar available!"))
     },
-    warning = function(w) {
-    },
     finally = {
     }
   )
