@@ -7,6 +7,6 @@ cols <- c(
 test_that("NFL Draft Positions", {
   skip_on_cran()
   x <- cfbd_draft_positions()
-  expect_equal(colnames(x), cols)
+  expect_setequal(colnames(x), cols)
   expect_s3_class(x, "data.frame")
 })
