@@ -26,8 +26,8 @@ test_that("CFB Game Box Advanced", {
   y <- cfbd_game_box_advanced(game_id = 401110720)
   expect_equal(nrow(x), 2)
   expect_equal(nrow(y), 2)
-  expect_equal(colnames(x), cols2)
-  expect_equal(colnames(y), cols2)
+  expect_setequal(colnames(x), cols2)
+  expect_setequal(colnames(y), cols2)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
