@@ -30,8 +30,8 @@ test_that("CFB Game Info", {
   x <- cfbd_game_weather(2019, week = 1, conference = "ACC")
 
   y <- cfbd_game_weather(2018, week = 4, conference = "Ind")
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
