@@ -1,7 +1,7 @@
 
 
 cols <- c(
-  "season", "week", "name", "position", "team", "opponent", "avg_PPA_all",
+  "season", "week", "season_type", "athlete_id", "name", "position", "team", "opponent", "avg_PPA_all",
   "avg_PPA_pass", "avg_PPA_rush"
 )
 
@@ -10,8 +10,8 @@ test_that("CFB Metrics PPA Games", {
   x <- cfbd_metrics_ppa_players_games(year = 2019, week = 4, team = "TCU")
 
   y <- cfbd_metrics_ppa_players_games(year = 2019, team = "Alabama", week = 11)
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
