@@ -15,8 +15,8 @@ test_that("CFB Metrics PPA Players Season", {
   x <- cfbd_metrics_ppa_players_season(year = 2019, team = "TCU")
 
   y <- cfbd_metrics_ppa_players_season(year = 2019, team = "Alabama")
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
