@@ -10,6 +10,6 @@ test_that("CFB Player Returning", {
 
   skip_on_cran()
   x <- cfbd_player_returning(year = 2020, team = "Florida State")
-  expect_equal(colnames(x), cols)
+  expect_setequal(colnames(x), cols)
   expect_s3_class(x, "data.frame")
 })
