@@ -15,17 +15,17 @@ test_that("CFB Poll Rankings", {
   z <- cfbd_rankings(year = 2013, season_type = "postseason")
   first_team_AP_13 <- z %>%
     filter(.data$poll == "AP Top 25" & .data$rank == 1) %>%
-    select(.data$school)
+    select("school")
 
   first_team_coaches_13 <- z %>%
     filter(.data$poll == "Coaches Poll" & .data$rank == 1) %>%
-    select(.data$school)
+    select("school")
 
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
-  expect_equal(colnames(z), cols)
-  expect_equivalent(first_team_AP_13, "Florida State")
-  expect_equivalent(first_team_coaches_13, "Florida State")
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
+  expect_setequal(colnames(z), cols)
+  expect_equal(dplyr::first(first_team_AP_13$school), "Florida State")
+  expect_equal(dplyr::first(first_team_coaches_13$school), "Florida State")
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
   expect_s3_class(z, "data.frame")
