@@ -19,9 +19,9 @@ test_that("CFB Ratings - Bill C.'s SP+", {
 
   z <- cfbd_ratings_sp(year = 2019, team = "LSU")
 
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
-  expect_equal(colnames(z), cols)
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
+  expect_setequal(colnames(z), cols)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
   expect_s3_class(z, "data.frame")
