@@ -8,9 +8,9 @@ test_that("CFB Recruiting Team", {
   y <- cfbd_recruiting_team(2016, team = "Virginia")
 
   z <- cfbd_recruiting_team(2011)
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
-  expect_equal(colnames(z), cols)
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
+  expect_setequal(colnames(z), cols)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
   expect_s3_class(z, "data.frame")
