@@ -8,6 +8,6 @@ cols <- c(
 test_that("CFB Transfer Portal", {
   skip_on_cran()
   x <- cfbd_recruiting_transfer_portal(year = 2021)
-  expect_equal(colnames(x), cols)
+  expect_setequal(colnames(x), cols)
   expect_s3_class(x, "data.frame")
 })
