@@ -7,8 +7,8 @@ test_that("CFB Team Matchup Records", {
   x <- cfbd_team_matchup_records("Texas", "Oklahoma")
 
   y <- cfbd_team_matchup_records("Texas A&M", "TCU", min_year = 1975)
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
