@@ -13,9 +13,9 @@ test_that("CFB Team Roster", {
   y <- cfbd_team_roster(2018, team = "Texas A&M")
 
   z <- cfbd_team_roster(2017)
-  expect_equal(colnames(x), cols)
-  expect_equal(colnames(y), cols)
-  expect_equal(colnames(z), cols)
+  expect_setequal(colnames(x), cols)
+  expect_setequal(colnames(y), cols)
+  expect_setequal(colnames(z), cols)
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
   expect_s3_class(z, "data.frame")
