@@ -1,6 +1,6 @@
 cols <- c(
   "venue_id", "name", "capacity", "grass", "city", "state",
-  "zip", "country_code", "location", "elevation", "year_constructed",
+  "zip", "country_code", "latitude", "longitude", "elevation", "year_constructed",
   "dome", "timezone"
 )
 
@@ -9,8 +9,7 @@ test_that("CFB Venues", {
 
   x <- cfbd_venues()
 
-  expect_equal(nrow(x), 351)
-  expect_equal(ncol(x), 13)
-  expect_equal(colnames(x), cols)
+  expect_setequal(ncol(x), length(cols))
+  expect_setequal(colnames(x), cols)
   expect_s3_class(x, "data.frame")
 })
