@@ -17,8 +17,8 @@ test_that("ESPN CFB Calendar", {
 
   y <- espn_cfb_calendar(year = 2020)
 
-  expect_equal(sort(colnames(x)), sort(cols))
-  expect_equal(sort(colnames(y)), sort(cols))
+  expect_setequal(sort(colnames(x)), sort(cols))
+  expect_setequal(sort(colnames(y)), sort(cols))
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
