@@ -11,7 +11,10 @@ test_that("ESPN CFB Schedule", {
     "game_id",
     "game_uid",
     "game_date",
+    "game_date_time",
     "attendance",
+    "date_valid",
+    "play_by_play_available",
     "home_team_name",
     "home_team_logo",
     "home_team_abb",
@@ -33,19 +36,13 @@ test_that("ESPN CFB Schedule", {
     "away_win",
     "away_record",
     "status_name",
-    "start_date"
+    "start_date",
+    "highlights"
   )
 
   x <- espn_cfb_schedule() %>%
     dplyr::select(
-      -dplyr::any_of(dplyr::starts_with("broadcast")),
-      -dplyr::any_of(dplyr::starts_with("passing")),
-      -dplyr::any_of(dplyr::starts_with("rushing")),
-      -dplyr::any_of(dplyr::starts_with("receiving")),
-    )
-
-  y <- espn_cfb_schedule(2021, week = 8) %>%
-    dplyr::select(
+      -dplyr::any_of(dplyr::starts_with("geo_")),
       -dplyr::any_of(dplyr::starts_with("broadcast")),
       -dplyr::any_of(dplyr::starts_with("passing")),
       -dplyr::any_of(dplyr::starts_with("rushing")),
@@ -53,8 +50,18 @@ test_that("ESPN CFB Schedule", {
       -dplyr::any_of(c("notes"))
     )
 
-  expect_equal(sort(colnames(x)), sort(cols))
-  expect_equal(sort(colnames(y)), sort(cols))
+  y <- espn_cfb_schedule(2021, week = 8) %>%
+    dplyr::select(
+      -dplyr::any_of(dplyr::starts_with("geo_")),
+      -dplyr::any_of(dplyr::starts_with("broadcast")),
+      -dplyr::any_of(dplyr::starts_with("passing")),
+      -dplyr::any_of(dplyr::starts_with("rushing")),
+      -dplyr::any_of(dplyr::starts_with("receiving")),
+      -dplyr::any_of(c("notes"))
+    )
+
+  expect_setequal(sort(colnames(x)), sort(cols))
+  expect_setequal(sort(colnames(y)), sort(cols))
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
