@@ -11,7 +11,9 @@ test_that("ESPN CFB Scoreboard", {
     "game_id",
     "game_uid",
     "game_date",
+    "game_date_time",
     "attendance",
+    "play_by_play_available",
     "home_team_name",
     "home_team_logo",
     "home_team_abb",
@@ -33,27 +35,33 @@ test_that("ESPN CFB Scoreboard", {
     "away_win",
     "away_record",
     "status_name",
-    "start_date"
+    "start_date",
+    "date_valid",
+    "highlights"
   )
 
   x <- espn_cfb_scoreboard() %>%
     dplyr::select(
+      -dplyr::any_of(dplyr::starts_with("geo_")),
       -dplyr::any_of(dplyr::starts_with("broadcast")),
       -dplyr::any_of(dplyr::starts_with("passing")),
       -dplyr::any_of(dplyr::starts_with("rushing")),
       -dplyr::any_of(dplyr::starts_with("receiving")),
+      -dplyr::any_of(c("notes"))
     )
 
-  y <- espn_cfb_scoreboard(date=20210101) %>%
+  y <- espn_cfb_scoreboard(date = 20210101) %>%
     dplyr::select(
+      -dplyr::any_of(dplyr::starts_with("geo_")),
       -dplyr::any_of(dplyr::starts_with("broadcast")),
       -dplyr::any_of(dplyr::starts_with("passing")),
       -dplyr::any_of(dplyr::starts_with("rushing")),
       -dplyr::any_of(dplyr::starts_with("receiving")),
+      -dplyr::any_of(c("notes"))
     )
 
-  expect_equal(sort(colnames(x)), sort(cols))
-  expect_equal(sort(colnames(y)), sort(cols))
+  expect_setequal(sort(colnames(x)), sort(cols))
+  expect_setequal(sort(colnames(y)), sort(cols))
   expect_s3_class(x, "data.frame")
   expect_s3_class(y, "data.frame")
 })
