@@ -8,6 +8,6 @@ cols <- c(
 test_that("CFB Metrics ESPN Win Probability", {
   skip_on_cran()
   x <- espn_metrics_wp(game_id = 401012356)
-  expect_equal(colnames(x), cols)
+  expect_setequal(colnames(x), cols)
   expect_s3_class(x, "data.frame")
 })
